import { EntitySyncConfig } from '../models/EntitySyncConfig';
import { SyncAdminUser } from '../models/SyncAdminUser';
import { SyncBuyer } from '../models/SyncBuyer';
import { SyncBuyerUserGroup } from '../models/SyncBuyerUserGroup';
import { SyncBuyerUser } from '../models/SyncBuyerUser';
import { SyncCategory } from '../models/SyncCategory';
import { SyncInventoryRecord } from '../models/SyncInventoryRecord';
import { SyncSupplier } from '../models/SyncSupplier';
import { SyncSupplierUser } from '../models/SyncSupplierUser';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class EntitySynchronization {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get the entity sync delivery configuration for AdminUsers Get the entity sync delivery configuration for AdminUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/get-admin-users|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    GetAdminUsers<TEntitySyncConfig extends EntitySyncConfig>(requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Create or update the entity sync delivery configuration for AdminUsers Create or update the entity sync delivery configuration for AdminUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/save-admin-users|api docs} for more info
     *
     * @param entitySyncConfig Required fields: DeliveryConfigID, SyncEntityChanged, SyncEntityDeleted
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveAdminUsers<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: EntitySyncConfig, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Delete the entity sync delivery configuration for AdminUsers Delete the entity sync delivery configuration for AdminUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/delete-admin-users|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteAdminUsers(requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update the entity sync delivery configuration for AdminUsers Partially update the entity sync delivery configuration for AdminUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/patch-admin-users|api docs} for more info
     *
     * @param entitySyncConfig
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    PatchAdminUsers<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: PartialDeep<EntitySyncConfig>, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Sync an admin user.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/sync-admin-user|api docs} for more info
     *
     * @param syncAdminUser Required fields: UserID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SyncAdminUser(syncAdminUser: SyncAdminUser, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Get the entity sync delivery configuration for Buyers Get the entity sync delivery configuration for Buyers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/get-buyers|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    GetBuyers<TEntitySyncConfig extends EntitySyncConfig>(requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Create or update the entity sync delivery configuration for Buyers Create or update the entity sync delivery configuration for Buyers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/save-buyers|api docs} for more info
     *
     * @param entitySyncConfig Required fields: DeliveryConfigID, SyncEntityChanged, SyncEntityDeleted
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveBuyers<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: EntitySyncConfig, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Delete the entity sync delivery configuration for Buyers Delete the entity sync delivery configuration for Buyers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/delete-buyers|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteBuyers(requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update the entity sync delivery configuration for Buyers Partially update the entity sync delivery configuration for Buyers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/patch-buyers|api docs} for more info
     *
     * @param entitySyncConfig
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    PatchBuyers<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: PartialDeep<EntitySyncConfig>, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Sync a buyer.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/sync-buyer|api docs} for more info
     *
     * @param syncBuyer Required fields: BuyerID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SyncBuyer(syncBuyer: SyncBuyer, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Get the entity sync delivery configuration for BuyerUserGroups Get the entity sync delivery configuration for BuyerUserGroups
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/get-buyer-user-groups|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    GetBuyerUserGroups<TEntitySyncConfig extends EntitySyncConfig>(requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Create or update the entity sync delivery configuration for BuyerUserGroups Create or update the entity sync delivery configuration for BuyerUserGroups
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/save-user-groups|api docs} for more info
     *
     * @param entitySyncConfig Required fields: DeliveryConfigID, SyncEntityChanged, SyncEntityDeleted
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveUserGroups<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: EntitySyncConfig, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Delete the entity sync delivery configuration for BuyerUserGroups Delete the entity sync delivery configuration for BuyerUserGroups
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/delete-user-groups|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteUserGroups(requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update the entity sync delivery configuration for BuyerUserGroups Partially update the entity sync delivery configuration for BuyerUserGroups
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/patch-buyer-user-groups|api docs} for more info
     *
     * @param entitySyncConfig
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    PatchBuyerUserGroups<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: PartialDeep<EntitySyncConfig>, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Sync a buyer user group.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/sync-buyer-user-group|api docs} for more info
     *
     * @param syncBuyerUserGroup Required fields: BuyerID, UserGroupID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SyncBuyerUserGroup(syncBuyerUserGroup: SyncBuyerUserGroup, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Get the entity sync delivery configuration for BuyerUsers Get the entity sync delivery configuration for BuyerUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/get-buyer-users|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    GetBuyerUsers<TEntitySyncConfig extends EntitySyncConfig>(requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Create or update the entity sync delivery configuration for BuyerUsers Create or update the entity sync delivery configuration for BuyerUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/save-buyer-users|api docs} for more info
     *
     * @param entitySyncConfig Required fields: DeliveryConfigID, SyncEntityChanged, SyncEntityDeleted
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveBuyerUsers<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: EntitySyncConfig, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Delete the entity sync delivery configuration for BuyerUsers Delete the entity sync delivery configuration for BuyerUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/delete-buyer-users|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteBuyerUsers(requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update the entity sync delivery configuration for BuyerUsers Partially update the entity sync delivery configuration for BuyerUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/patch-buyer-users|api docs} for more info
     *
     * @param entitySyncConfig
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    PatchBuyerUsers<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: PartialDeep<EntitySyncConfig>, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Sync a buyer user.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/sync-buyer-user|api docs} for more info
     *
     * @param syncBuyerUser Required fields: BuyerID, UserID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SyncBuyerUser(syncBuyerUser: SyncBuyerUser, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Get the entity sync delivery configuration for Categories Get the entity sync delivery configuration for Categories
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/get-categories|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    GetCategories<TEntitySyncConfig extends EntitySyncConfig>(requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Create or update the entity sync delivery configuration for Categories Create or update the entity sync delivery configuration for Categories
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/save-categories|api docs} for more info
     *
     * @param entitySyncConfig Required fields: DeliveryConfigID, SyncEntityChanged, SyncEntityDeleted
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveCategories<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: EntitySyncConfig, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Delete the entity sync delivery configuration for Categories Delete the entity sync delivery configuration for Categories
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/delete-categories|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteCategories(requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update the entity sync delivery configuration for Categories Partially update the entity sync delivery configuration for Categories
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/patch-categories|api docs} for more info
     *
     * @param entitySyncConfig
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    PatchCategories<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: PartialDeep<EntitySyncConfig>, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Sync a category.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/sync-category|api docs} for more info
     *
     * @param syncCategory Required fields: CatalogID, CategoryID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SyncCategory(syncCategory: SyncCategory, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Get the entity sync delivery configuration for InventoryRecords Get the entity sync delivery configuration for InventoryRecords
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/get-inventory-records|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    GetInventoryRecords<TEntitySyncConfig extends EntitySyncConfig>(requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Create or update the entity sync delivery configuration for InventoryRecords Create or update the entity sync delivery configuration for InventoryRecords
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/save-inventory-records|api docs} for more info
     *
     * @param entitySyncConfig Required fields: DeliveryConfigID, SyncEntityChanged, SyncEntityDeleted
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveInventoryRecords<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: EntitySyncConfig, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Delete the entity sync delivery configuration for InventoryRecords Delete the entity sync delivery configuration for InventoryRecords
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/delete-inventory-records|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteInventoryRecords(requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update the entity sync delivery configuration for InventoryRecords Partially update the entity sync delivery configuration for InventoryRecords
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/patch-inventory-records|api docs} for more info
     *
     * @param entitySyncConfig
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    PatchInventoryRecords<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: PartialDeep<EntitySyncConfig>, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Sync an inventory record.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/sync-inventory-record|api docs} for more info
     *
     * @param syncInventoryRecord Required fields: ProductID, InventoryRecordID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SyncInventoryRecord(syncInventoryRecord: SyncInventoryRecord, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Sync a supplier.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/sync-supplier|api docs} for more info
     *
     * @param syncSupplier Required fields: SupplierID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SyncSupplier(syncSupplier: SyncSupplier, requestOptions?: RequestOptions): Promise<void>;
    /**
     * Get the entity sync delivery configuration for Suppliers Get the entity sync delivery configuration for Suppliers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/get-suppliers|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    GetSuppliers<TEntitySyncConfig extends EntitySyncConfig>(requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Create or update the entity sync delivery configuration for Suppliers Create or update the entity sync delivery configuration for Suppliers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/save-suppliers|api docs} for more info
     *
     * @param entitySyncConfig Required fields: DeliveryConfigID, SyncEntityChanged, SyncEntityDeleted
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveSuppliers<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: EntitySyncConfig, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Delete the entity sync delivery configuration for Suppliers Delete the entity sync delivery configuration for Suppliers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/delete-suppliers|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteSuppliers(requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update the entity sync delivery configuration for Suppliers Partially update the entity sync delivery configuration for Suppliers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/patch-suppliers|api docs} for more info
     *
     * @param entitySyncConfig
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    PatchSuppliers<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: PartialDeep<EntitySyncConfig>, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Get the entity sync delivery configuration for SupplierUsers Get the entity sync delivery configuration for SupplierUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/get-supplier-users|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    GetSupplierUsers<TEntitySyncConfig extends EntitySyncConfig>(requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Create or update the entity sync delivery configuration for SupplierUsers Create or update the entity sync delivery configuration for SupplierUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/save-supplier-users|api docs} for more info
     *
     * @param entitySyncConfig Required fields: DeliveryConfigID, SyncEntityChanged, SyncEntityDeleted
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SaveSupplierUsers<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: EntitySyncConfig, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Delete the entity sync delivery configuration for SupplierUsers Delete the entity sync delivery configuration for SupplierUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/delete-supplier-users|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    DeleteSupplierUsers(requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update the entity sync delivery configuration for SupplierUsers Partially update the entity sync delivery configuration for SupplierUsers
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/patch-supplier-users|api docs} for more info
     *
     * @param entitySyncConfig
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    PatchSupplierUsers<TEntitySyncConfig extends EntitySyncConfig>(entitySyncConfig: PartialDeep<EntitySyncConfig>, requestOptions?: RequestOptions): Promise<RequiredDeep<TEntitySyncConfig>>;
    /**
     * Sync a supplier user.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/entity-synchronization/sync-supplier-user|api docs} for more info
     *
     * @param syncSupplierUser Required fields: SupplierID, UserID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    SyncSupplierUser(syncSupplierUser: SyncSupplierUser, requestOptions?: RequestOptions): Promise<void>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * EntitySynchronization.As().List() // lists EntitySynchronization using the impersonated users' token
     */
    As(): this;
}
declare const _default: EntitySynchronization;
export default _default;
