import { OrderSyncConfig } from '../models/OrderSyncConfig';
import { PartialDeep } from '../models/PartialDeep';
import { RequiredDeep } from '../models/RequiredDeep';
import { RequestOptions } from '../models/RequestOptions';
declare class OrderSynchronization {
    private impersonating;
    /**
    * @ignore
    * not part of public api, don't include in generated docs
    */
    constructor();
    /**
     * Get a single order sync.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/order-synchronization/get|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Get<TOrderSyncConfig extends OrderSyncConfig>(requestOptions?: RequestOptions): Promise<RequiredDeep<TOrderSyncConfig>>;
    /**
     * Create or update an order sync. If an object with the same ID already exists, it will be overwritten.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/order-synchronization/save|api docs} for more info
     *
     * @param orderSyncConfig Required fields: DeliveryConfigID
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Save<TOrderSyncConfig extends OrderSyncConfig>(orderSyncConfig: OrderSyncConfig, requestOptions?: RequestOptions): Promise<RequiredDeep<TOrderSyncConfig>>;
    /**
     * Delete an order sync.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/order-synchronization/delete|api docs} for more info
     *
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Delete(requestOptions?: RequestOptions): Promise<void>;
    /**
     * Partially update an order sync.
     * Check out the {@link https://ordercloud.io/api-reference/integrations/order-synchronization/patch|api docs} for more info
     *
     * @param orderSyncConfig
     * @param requestOptions.accessToken Provide an alternative token to the one stored in the sdk instance (useful for impersonation).
     * @param requestOptions.cancelToken Provide an [axios cancelToken](https://github.com/axios/axios#cancellation) that can be used to cancel the request.
     * @param requestOptions.requestType Provide a value that can be used to identify the type of request. Useful for error logs.
     */
    Patch<TOrderSyncConfig extends OrderSyncConfig>(orderSyncConfig: PartialDeep<OrderSyncConfig>, requestOptions?: RequestOptions): Promise<RequiredDeep<TOrderSyncConfig>>;
    /**
     * @description
     * enables impersonation by calling the subsequent method with the stored impersonation token
     *
     * @example
     * OrderSynchronization.As().List() // lists OrderSynchronization using the impersonated users' token
     */
    As(): this;
}
declare const _default: OrderSynchronization;
export default _default;
